@@ -5,7 +5,15 @@ use Log::Log4perl;
 use warnings;
 use strict;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
+
+has history          => sub { [] };
+has max_history_size => 10;
+
+# development notes: Mojo::Log provides 'path' 'handle' and 'format'
+# to handle log location and formatting. Those make no sense in a Log4perl
+# environment (where you can set appenders as you wish) so they are
+# not implemented here.
 
 sub new {
 	my ($class, $conf_file, $watch) = (@_);
@@ -62,7 +70,13 @@ sub _message {
 	local $Log::Log4perl::caller_depth
       = $Log::Log4perl::caller_depth + $depth;
 
-	$self->_get_logger( $depth )->$level( @message );
+	if ($self->_get_logger( $depth )->$level( @message )) {
+		my $history = $self->history;
+		my $max     = $self->max_history_size;
+		push @$history => [ time, $level, @message ];
+		splice (@$history, 0, scalar @$history - $max)
+		    if scalar @$history > $max;
+	}
 	return $self;
 }
 
@@ -325,18 +339,33 @@ Finally, there's the Carp functions that do just what the Carp functions do, but
 
 =head1 ATTRIBUTES
 
-The original C<handle> and C<path> attributes from C<< Mojo::Log >> are not implemented as they make little sense in a Log4perl environment. The only attribute available, therefore, is C<level>.
+The original C<handle> and C<path> attributes from C<< Mojo::Log >> are not implemented as they make little sense in a Log4perl environment. The following attributes are still available:
 
 =head2 C<level>
 
   my $level = $logger->level();
   
-This will return an UPPERCASED string with the current log level (C<'DEBUG'>, C<'INFO'>, ...). You can also use this to force a level of your choosing:
+This will return an UPPERCASED string with the current log level (C<'DEBUG'>, C<'INFO'>, ...).
+
+Note: You can also use this to force a level of your choosing:
 
   $logger->level('warn');  # forces 'warn' level (case-insensitive)
 
-But you really shouldn't do that at all, as it breaks log4perl's configuration structure. The whole point of Log4perl is letting you setup your logging from outside your code. So, once again: don't do this.
+But you really shouldn't do that at all, as it breaks log4perl's configuration structure. The whole point of Log4perl is letting you setup your logging from outside your code. So, once again: B<don't do this>.
 
+=head2 C<history>
+
+This returns the last few logged messages as an array reference in the format:
+
+    [
+        [ 'timestamp', 'level', 'message' ], # older first
+        [ 'timestamp', 'level', 'message' ],
+        ...
+    ]
+
+=head2 C<max_history_size>
+
+Maximum number of messages to be kept in the history buffer (see above). Defaults to 10.
 
 =head1 AUTHOR
 
@@ -391,7 +420,7 @@ L<< Log::Log4perl >>, L<< Mojo::Log >>, L<< Mojo >>, L<< Mojolicious >>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2009-2013 Breno G. de Oliveira, all rights reserved.
+Copyright 2009-2014 Breno G. de Oliveira, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
